@@ -46,8 +46,8 @@
 #include <rpc/clnt.h>
 #include <rpc/xdr.h>
 #include <sys/socket.h>
-#undef NIS
-#include <rpcsvc/nis.h>
+
+#include "nis.h"
 
 #if defined(LIBC_SCCS) && !defined(lint)
 #endif
@@ -77,8 +77,6 @@ static bool_t	authdes_marshal(AUTH *, XDR *);
 static bool_t	authdes_validate(AUTH *, struct opaque_auth *);
 static bool_t	authdes_refresh(AUTH *, void *);
 static void	authdes_destroy(AUTH *);
-extern int key_gendes(des_block *deskey);
-extern int getpublickey (const char *, char *);
 
 static struct auth_ops *authdes_ops(void);
 
@@ -225,7 +223,6 @@ authdes_pk_seccreate(const char *servername, netobj *pkey, u_int window,
 		goto failed;
 	}
 	ad->ad_nis_srvr = NULL; /* not needed any longer */
-	auth_get(auth);		/* Reference for caller */
 	return (auth);
 
 failed:
@@ -399,7 +396,7 @@ authdes_validate(AUTH *auth, struct opaque_auth *rverf)
 	/*
 	 * validate
 	 */
-	if (bcmp((char *)&ad->ad_timestamp, (char *)&verf.adv_timestamp,
+	if (memcmp((char *)&ad->ad_timestamp, (char *)&verf.adv_timestamp,
 		 sizeof(struct timeval)) != 0) {
 		LIBTIRPC_DEBUG(1, ("authdes_validate: verifier mismatch"));
 		return (FALSE);
