@@ -41,16 +41,6 @@
 #ifndef _RPC_SVC_AUTH_H
 #define _RPC_SVC_AUTH_H
 
-#include <rpc/rpcsec_gss.h>
-
-typedef struct {
-	bool_t			established;
-	rpc_gss_service_t	service;
-	u_int			qop_rcvd;
-	void			*context;
-	u_int			seq_num;
-} svc_rpc_gss_parms_t;
-
 /*
  * Interface to server-side authentication flavors.
  */
@@ -63,8 +53,6 @@ typedef struct SVCAUTH {
 		int     (*svc_ah_destroy)(struct SVCAUTH *);
 		} *svc_ah_ops;
 	caddr_t svc_ah_private;
-	svc_rpc_gss_parms_t svc_gss_params;
-	rpc_gss_rawcred_t raw_cred;
 } SVCAUTH;
 
 #define SVCAUTH_WRAP(auth, xdrs, xfunc, xwhere) \
